@@ -140,10 +140,11 @@ class InitialiseDomainModel(InitialiseDomainModelBase):
         plugins.create('apacheconfig')
     
     def createServicePlugins(self):
+        # only create plugins which have *no* external dependencies beyond
+        # those for base KForge system (so no trac, svn etc)
         plugins = self.registry.plugins
-        plugins.create('svn')
-        plugins.create('trac')
-        plugins.create('mailman')
+        plugins.create('www')
+        plugins.create('dav')
     
     def createTestPlugins(self):
         plugins = self.registry.plugins
