@@ -19,6 +19,7 @@ class SystemDictionary(dm.dictionary.SystemDictionary):
  
     def setDefaultWords(self):
         super(SystemDictionary, self).setDefaultWords()
-        self['member_role'] = 'Friend'
-        self['plugin_package'] = 'kforge.plugin'
+        self[MEMBER_ROLE_NAME] = 'Friend'
+        self[PLUGIN_PACKAGE_NAME] = 'kforge.plugin'
+        self[TRAC_ADMIN_SCRIPT] = 'trac-admin'
 
