@@ -17,32 +17,42 @@ class TestHasManyAttribute(AdminTestCase):
         super(TestHasManyAttribute, self).tearDown()
 
     def testMemberList(self):
+        location = self.url_scheme.url_for('admin',
+                offset='Project/administration/members/')
         self.getAssertContent(
-            '/admin/model/Project/administration/members/',
+            location,
             'admin'
         )
 
     def testMemberCreate(self):
+        location = self.url_scheme.url_for('admin',
+                offset='create/Project/administration/members/')
         self.getAssertContent(
-            '/admin/model/create/Project/administration/members/',
+            location, 
             'Create Member'
         )
 
     def testMemberRead(self):
+        location = self.url_scheme.url_for('admin',
+                offset='create/Project/administration/members/admin/')
         self.getAssertContent(
-            '/admin/model/Project/administration/members/admin/',
+            location,
             'admin'
         )
 
     def testMemberUpdate(self):
+        location = self.url_scheme.url_for('admin',
+                offset='update/Project/administration/members/admin/')
         self.getAssertContent(
-            '/admin/model/update/Project/administration/members/admin/',
+            location, 
             'Update Member'
         )
 
     def testMemberDelete(self):
+        location = self.url_scheme.url_for('admin',
+                offset='delete/Project/administration/members/admin/')
         self.getAssertContent(
-            '/admin/model/delete/Project/administration/members/admin/',
+            location, 
             'Delete Member'
         )
 
