@@ -14,7 +14,10 @@ class TestReadPersons(KuiTestCase):
    
     def testPersonIndex(self):
         offset = self.url_scheme.url_for('person')
-        self.getAssertContent(offset, 'Registered people')
+        self.getAssertContent(offset, [
+            'Registered people',
+            'There are %s registered people' % self.registry.persons.count()
+        ])
 
     def testPersonSearch(self):
         params = {'userQuery': 'z'}
