@@ -13,3 +13,8 @@ class TestProjectListView(ViewTestCase):
 
     viewClass = ProjectListView
 
+    def getRequiredViewContext(self):
+        return {
+            'objectCount': self.registry.projects.count()
+        }
+
