@@ -7,6 +7,8 @@ class Person(dm.dom.person.Person):
 
     memberships = HasMany('Member', 'project')
 
+    isUnique = False
+
     def delete(self):
         for member in self.memberships:
             member.delete()
@@ -21,3 +23,7 @@ class Person(dm.dom.person.Person):
     def getLabelValue(self):
         return self.fullname or self.name
 
+    def getFirstName(self):
+        name = self.getLabelValue()
+        parts = name.split(' ')
+        return parts[0]
