@@ -6,14 +6,15 @@ import Cookie
 class ModPythonHandler(object):
 
     cookieClientIdentifiers = ['Mozilla', 'Links', 'Lynx', 'w3m'] 
-    app = None
 
     def __init__(self, request):
         self.request = request
+        self.authuserName = ''
+        self.application = None
 
     def authorise(self):
         self.initHandler()
-        return HTTP_UNAUTHORIZED
+        return DEFER_OR_DENY
 
     def initHandler(self):
         self.isAccessAllowed = False
@@ -30,11 +31,10 @@ class ModPythonHandler(object):
 
     def initApplication(self):
         import kforge.soleInstance
-        self.app = kforge.soleInstance.application
+        self.application = kforge.soleInstance.application
 
     def initAuthuserNameFromDictionary(self):
-        self.authuserName = self.app.dictionary[VISITOR_NAME]
-        self.request.user = self.authuserName
+        self.authuserName = self.application.dictionary[VISITOR_NAME]
 
     def validateRequestUri(self):
         return self.validateUri(self.request.uri)
@@ -43,10 +43,10 @@ class ModPythonHandler(object):
         "True if location has at least than two directories."
         path = self.normalizeUriPath(uri)
         if len(path.split('/')) < 2:
-            self.loggerDebug('URI not validated: %s' % uri)
+            self.logDebug('URI not validated: %s' % uri)
             return False
         else:
-            self.loggerDebug('URI validiated: %s' % uri)
+            self.logDebug('URI validiated: %s' % uri)
             return True
    
     def normalizeUriPath(self, uri):
@@ -57,29 +57,29 @@ class ModPythonHandler(object):
 
     def isCookieClient(self):
         "True if client supports cookies and redirection."
-        http_user_agent = self.request.subprocess_env.get('HTTP_USER_AGENT', '')
+        user_agent = self.request.subprocess_env.get('HTTP_USER_AGENT', '')
         isCookieClient = False
         for identifier in self.cookieClientIdentifiers:
-            if identifier in http_user_agent:
+            if identifier in user_agent:
                 isCookieClient = True
                 break
-        if self.app.debug:
+        if self.application.debug:
             if isCookieClient:
-                self.loggerDebug('Cookie client making request.')
+                self.logDebug('Cookie client making request.')
             else:
-                self.loggerDebug('Basic client making request.')
-            self.loggerDebug('User-Agent: %s' % http_user_agent)
+                self.logDebug('Basic client making request.')
+            self.logDebug('User-Agent: %s' % user_agent)
         return isCookieClient
 
     def checkAccess(self):
         isAccessAllowed = False
-        if self.app.debug:
+        if self.application.debug:
             message = 'Checking access for: %s, %s, %s' % (
                 self.authuserName,
                 self.request.uri,
                 self.request.method
             )
-            self.loggerDebug(message)
+            self.logDebug(message)
         try:
             import kforge.apache.urlpermission as urlpermission
             isAccessAllowed = urlpermission.isAllowedAccess(
@@ -88,27 +88,34 @@ class ModPythonHandler(object):
                 self.request.method
             )
         except Exception, inst:
-            if self.app.debug:
+            if self.application.debug:
                 message = 'Exception: %s' % str(inst)
-                self.loggerDebug(message)
+                self.logDebug(message)
             raise
-        if self.app.debug:
+        if self.application.debug:
             if isAccessAllowed:
                 message = "    ...allowing access."
-                self.loggerDebug(message)
+                self.logDebug(message)
             else:
                 message = "    ...not allowing access."
-                self.loggerDebug(message)
+                self.logDebug(message)
         self.isAccessAllowed = isAccessAllowed
         return isAccessAllowed
 
-    def loggerDebug(self, message):
+    def logDebug(self, message):
         message = "%s handler: %s" % (
             self.__class__.__name__, 
             message
         )   
-        self.app.logger.debug(message)
+        self.application.logger.debug(message)
 
+    def setRequestUser(self, userName):
+        if type(userName) == unicode:
+            userName = userName.encode('utf-8')
+        if type(userName) != str:
+            userName = str(userName)
+        self.request.user = userName
+        
 
 class PythonAccessHandler(ModPythonHandler):
 
@@ -116,12 +123,33 @@ class PythonAccessHandler(ModPythonHandler):
         super(PythonAccessHandler, self).__init__(*args, **kwds)
         self.session = None
 
+    def authorise(self):
+        self.initHandler()
+        if not self.validateRequestUri():
+            return STOP_AND_DENY
+        if self.isCookieClient():
+            self.initAuthuserNameFromCookie()
+            if self.checkAccess():
+                if self.session:
+                    # Setting request.user only under above conditions.
+                    self.setRequestUser(self.authuserName)
+                return STOP_AND_APPROVE
+            else:
+                self.setLoginRedirect()
+                return STOP_AND_DENY
+        else:
+            self.initAuthuserNameFromDictionary()
+            if self.checkAccess():
+                return STOP_AND_APPROVE
+            else:
+                return DEFER_OR_DENY
+
     def initAuthuserNameFromCookie(self):
         self.authuserName = None
         authCookieValue = self.getAuthCookieValue()
         if authCookieValue:
-            if self.app.debug:
-                self.loggerDebug('Cookie: %s' % authCookieValue)
+            if self.application.debug:
+                self.logDebug('Cookie: %s' % authCookieValue)
             import dm.view.base
             view = dm.view.base.ControlledAccessView(None)
             view.setSessionFromCookieString(authCookieValue)
@@ -129,15 +157,14 @@ class PythonAccessHandler(ModPythonHandler):
                 self.session = view.session
                 self.authuserName = self.session.person.name
             else:
-                self.authuserName = self.app.dictionary[VISITOR_NAME]
+                self.authuserName = self.application.dictionary[VISITOR_NAME]
         else:
-            if self.app.debug:
-                self.loggerDebug('No session cookie in request.')
-            self.authuserName = self.app.dictionary[VISITOR_NAME]
-        self.request.user = self.authuserName
-
+            if self.application.debug:
+                self.logDebug('No session cookie in request.')
+            self.authuserName = self.application.dictionary[VISITOR_NAME]
+        
     def getAuthCookieValue(self):
-        authCookieName = self.app.dictionary[AUTH_COOKIE_NAME]
+        authCookieName = self.application.dictionary[AUTH_COOKIE_NAME]
         return self.getCookieValue(authCookieName)
 
     def getCookieValue(self, cookieName):
@@ -163,22 +190,35 @@ class PythonAccessHandler(ModPythonHandler):
         current_uri = url_scheme.get_host() + self.request.uri
         redirectUri += current_uri
         self.request.err_headers_out.add('Location', redirectUri)
-        if self.app.debug:
-            self.loggerDebug('Redirecting to %s.' % redirectUri)
+        if self.application.debug:
+            self.logDebug('Redirecting to %s.' % redirectUri)
         self.request.status = HTTP_MOVED_TEMPORARILY
 
 
 class PythonAuthenHandler(ModPythonHandler):
 
+    def authorise(self):
+        self.initHandler()
+        if not self.validateRequestUri():
+            return STOP_AND_DENY
+        if self.isCookieClient():
+            self.logDebug("Cookie clients shouldn't get here.")
+            return STOP_AND_DENY
+        self.initAuthuserNameFromBasicPrompt()
+        if self.checkAccess():
+            return STOP_AND_APPROVE
+        else:
+            return DEFER_OR_DENY
+
     def initAuthuserNameFromBasicPrompt(self):
-        pw = self.request.get_basic_auth_pw()
-        if self.app.debug:
-            self.loggerDebug('Running initAuthuserNameFromBasicPrompt. Current user is %s.' % self.request.user)
+        password = self.request.get_basic_auth_pw()
+        if self.application.debug:
+            msg = 'Running initAuthuserNameFromBasicPrompt.'
+            msg += ' Current user is %s.' % self.request.user
+            self.logDebug(msg)
         import kforge.apache.urlpermission as urlpermission
         self.authuserName = urlpermission.getVisitorName(
             self.request.user,
-            pw
+            password
         )
-        self.request.user = self.authuserName
-
 
