@@ -4,19 +4,23 @@ from kforge.handlers.apachecodes import *
 
 class ProjectAccessHandler(PythonAccessHandler):
     """
-    Responsible for responding to and access control based upon session
+    Responsible for authentication and access control based upon session
     cookies, and for redirecting to the KForge login page or deferring control
     to the authen handler if access is not allowed, for clients which do 
     support cookies (such as Mozilla, Lynx, etc.).
     
-    Please Note: ModPython access handlers must return OK to statisfy
-    Apache's 'Satisfy any' condition, after which no further handling
-    will be triggered. Returning HTTP_OK does not have the same
-    effect, and further handlers may triggered wrongly. To repeat, the
-    'Satisy any' condition is looking for any handler that returns 0.
+    Note Well: To statisfy Apache's 'Satisfy any' condition, thereby stopping
+    further handling of the mod_python request (so that e.g. a basic auth
+    dialog prompt is not raised in a user's browser for allowed visitor access
+    to controlled application services) mod_python access handlers, such as
+    this one, must return OK or HTTP_FORBIDDEN (integer values of 0 or 403
+    respectively) from the authorise() method. Returning HTTP_OK does not have
+    the same effect, and further handlers may triggered wrongly. To repeat, 
+    the 'Satisy any' condition looks for any handler that returns 0 or 403.
 
-        return OK       #      OK == 0     handling stops
-        #return HTTP_OK # HTTP_OK == 200   handling would continue
+        return OK               # OK == 0               handling stops
+        return HTTP_FORBIDDEN   # HTTP_FORBIDDEN == 403 handling stops
+        return HTTP_OK          # HTTP_OK == 200        handling continues
 
     Redirect from an Authen Handler
     -------------------------------
@@ -81,24 +85,7 @@ class ProjectAccessHandler(PythonAccessHandler):
     --]]
     """
 
-    def authorise(self):
-        self.initHandler()
-        if not self.validateRequestUri():
-            return HTTP_FORBIDDEN
-        if self.isCookieClient(): 
-            self.initAuthuserNameFromCookie()
-            if self.checkAccess():
-                return OK
-            else:
-                self.setLoginRedirect()
-                # return HTTP_UNAUTHORIZED
-                return HTTP_FORBIDDEN   # See above.
-        else:
-            self.initAuthuserNameFromDictionary()
-            if self.checkAccess():
-                return OK
-            else:
-                return HTTP_UNAUTHORIZED
+    pass
 
 
 class ProjectAuthenHandler(PythonAuthenHandler):
@@ -108,19 +95,8 @@ class ProjectAuthenHandler(PythonAuthenHandler):
     which don't support cookies (such as DAV, SVN, etc.).
     
     """
-    
-    def authorise(self):
-        self.initHandler()
-        if not self.validateRequestUri():
-            return HTTP_FORBIDDEN
-        if self.isCookieClient():
-            self.loggerDebug("Cookie clients shouldn't get here.")
-            return HTTP_FORBIDDEN
-        self.initAuthuserNameFromBasicPrompt()
-        if self.checkAccess():
-            return OK
-        else:
-            return HTTP_UNAUTHORIZED
+
+    pass
 
 
 def accesshandler(request):
