@@ -44,6 +44,23 @@ class AbstractServicePlugin(dm.plugin.base.PluginBase):
         """
         return ''
 
+    def getApacheConfigCommon(self):
+        """
+        Return a fragment of Apache config that is only needed once per plugin
+        per virtual host (so common across all instances
+        """
+        return ''
+
+    def getApacheConfig(self, service):
+        """
+        Returns a fragment of apache config appropriate for the plugin instance
+        The fragment can use the variables defined in the dictionary in
+            ApacheConfigBuilder.getServiceSection
+        by inserting them as %(var_name)s
+        Alternatively it can build the config itself
+        """
+        return ''
+
 
 class ServicePlugin(AbstractServicePlugin):
     
