@@ -1,8 +1,19 @@
 """
-Dav Plugin
+KForge dav Plugin.
 
-This gives dav access to the project directory and all subdirectories.
-As such does not create its own plugin directory
+Enabling this plugin gives dav access to the project directory and all
+subdirectories.
+
+## Installation ##
+
+1. Dependencies. To create services using this plugin you must have installed
+   the following external applications:
+
+   * Apache dav module (mod_dav). Note that on many systems this will be
+     installed by default.
+
+2. KForge config file. You do not need to add anything to the KForge config
+   file.
 """
 import os
 import shutil
