@@ -6,24 +6,30 @@ import dm.plugin.factory
 # so could replace there and get rid of this altogether ...
 # (in dm also used from dm.command.plugin but that is not used I think ...)
 
+# Todo: Make this a KForge error.
+class MissingPluginEntryPoint(Exception): pass
+
 class PluginFactory(dm.plugin.factory.PluginFactory):
 
-    def getPlugin(self, domainObject):
-        pluginName = domainObject.name
-        pluginClass = self.getPluginClass(pluginName)
-        return pluginClass(domainObject)
-
     def getPluginClass(self, name):
-        entrypoint = self.getEntryPoint(name)
-        pluginClass = entrypoint.load()
+        pluginClass = super(PluginFactory, self).getPluginClass(name)
+        if not pluginClass:
+            try:
+                entrypoint = self.getEntryPoint(name)
+            except MissingPluginEntryPoint, inst:
+                msg = "Could not find plugin class either in plugin directory"
+                msg += " or in otherwise defined location within a setuptools"
+                msg += " entry point: %s" % str(inst)
+                raise Excpetion, msg
+            pluginClass = entrypoint.load()
         return pluginClass
 
     def getEntryPoint(self, name):
         for entrypoint in pkg_resources.iter_entry_points('kforge.plugins'):
             if entrypoint.name == name:
                 return entrypoint
-        msg = 'No plugin entry point found for plugin: %s' % name
-        raise Exception(msg)
+        msg = 'No entry point found for plugin: %s' % name
+        raise MissingPluginEntryPoint(msg)
 
     def getEntryPoints(self):
         entrypoints = []
