@@ -74,6 +74,8 @@ class Plugin(kforge.plugin.base.NonServicePlugin):
         return out
 
     def onProjectCreate(self, project):
+        if self.dictionary[DB_MIGRATION_IN_PROGRESS]:
+            return
         msg = 'Project created: %s' % project.name
         admins = self._getProjectAdmins(project)
         sysadmins = self._getSystemAdmins()
@@ -81,6 +83,8 @@ class Plugin(kforge.plugin.base.NonServicePlugin):
         self.notifyListeners(msg, sysadmins)
 
     def onProjectDelete(self, project):
+        if self.dictionary[DB_MIGRATION_IN_PROGRESS]:
+            return
         msg = 'Project deleted: %s' % project.name
         admins = self._getProjectAdmins(project)
         sysadmins = self._getSystemAdmins()
@@ -88,6 +92,8 @@ class Plugin(kforge.plugin.base.NonServicePlugin):
         self.notifyListeners(msg, sysadmins)
        
     def onPersonCreate(self, person):
+        if self.dictionary[DB_MIGRATION_IN_PROGRESS]:
+            return
         msg = 'Person created: %s' % person.name
         sysadmins = self._getSystemAdmins()
         self.notifyListeners(msg, sysadmins)
