@@ -1,16 +1,16 @@
 """
-KForge svn (subversion) plugin.
+KForge svn (Subversion) plugin.
 
-Enabling this plugin allows users to create subversion services to provide
-subversion repositories for their project.
+Enabling this plugin allows users to create Subversion services to provide
+Subversion repositories for their project.
 
 ## Installation ##
 
 1. Dependencies. To create services using this plugin you must have installed
    the following external applications:
 
-   * subversion
-   * Apache modules to provide access to subversion through apache (e.g. on
+   * Subversion
+   * Apache modules to provide access to Subversion through Apache (e.g. on
      debian the libapache2-svn package must be installed and the associated
      modules enabled).
 
@@ -18,7 +18,11 @@ subversion repositories for their project.
    file.
 
 3. Install and enable this plugin in the usual way (see the KForge
-   Documentation for details)
+   Documentation for details).
+
+ $ kforge-admin plugin enable svn
+ $ kforge-admin plugin disable svn
+
 """
 import os
 import commands
@@ -36,11 +40,16 @@ class Plugin(kforge.plugin.base.ServicePlugin):
     
     def onServiceCreate(self, service):
         if service and service.plugin and service.plugin.name == 'svn':
+            self.ensureProjectPluginDirectoryExists(service)
+            msg = 'SvnPlugin: Creating %s service stuff...' % (
+                service
+            )
+            self.log(msg)
             path = service.getDirPath()
             self.assertNotFileForPath(path)
             self.utils.createRepository(path)
             self.assertFileForPath(path)
-            msg = 'SvnPlugin: Created service %s on path: %s)' % (
+            msg = 'SvnPlugin: Created %s service stuff on path: %s)' % (
                 service, path
             )
             self.log(msg)
@@ -79,16 +88,16 @@ class Plugin(kforge.plugin.base.ServicePlugin):
         return config
 
     helpMessage = '''
-<p>This service provides a <a href="http://subversion.tigris.org/">subversion</a> repository located at:</p>
+<p>This service provides a <a href="http://subversion.tigris.org/">Subversion</a> repository located at:</p>
 <p style="text-align: center"><a href="%(url)s">%(url)s</a></p>
-<p>A subversion repository is a sharable versioned filesystem. To find out more about them see the <a href="http://svnbook.red-bean.com/">subversion book</a>. You can access the material in the repository in one of the following ways (provided you have read permissions):</p>
+<p>A Subversion repository is a sharable versioned filesystem. To find out more about them see the <a href="http://svnbook.red-bean.com/">Subversion book</a>. You can access the material in the repository in one of the following ways (provided you have read permissions):</p>
 <ul>
-    <li>Browse the material online by following the link to the subversion repository in your browser.</li>
+    <li>Browse the material online by following the link to the Subversion repository in your browser.</li>
     <li>'Check out' the repository with a suitable Subversion client. For example, if you are using the command line client, you would do:<br />
     <code>$ svn checkout %(url)s --username username</code><br /></li>
 </ul>
-<p>For more information on the command line client see the subversion book (chapter 3). Alternatively there is <a href="http://tortoisesvn.tigris.org/">Tortoise SVN</a>, a GUI client that integrates with Windows explorer. It has a <a href="http://tortoisesvn.net/doc_release">detailed manual</a> with chapter 5 covering 'daily use' -- checking out, committing etc.</p>
-<p>Note that if you wish to 'commit' work to the repository you must have a role on the project that includes 'write' permissions on subversion services.</p>
+<p>For more information on the command line client see the Subversion book (chapter 3). Alternatively there is <a href="http://tortoisesvn.tigris.org/">Tortoise SVN</a>, a GUI client that integrates with Windows explorer. It has a <a href="http://tortoisesvn.net/doc_release">detailed manual</a> with chapter 5 covering 'daily use' -- checking out, committing etc.</p>
+<p>Note that if you wish to 'commit' work to the repository you must have a role on the project that includes 'write' permissions on Subversion services.</p>
 '''
 
     def getUserHelp(self, service):
@@ -140,7 +149,7 @@ class SvnUtils(object):
 
     def deleteRepository(self, path):
         """
-        Destroys subversion repository file system.
+        Destroys Subversion repository file system.
         @path: see definition of path for createRepository
         """
         fullPath = self.getRepositoryPath(path)
