@@ -61,6 +61,7 @@ class Plugin(kforge.plugin.base.ServicePlugin):
     
     def onServiceCreate(self, service):
         if service and service.plugin and service.plugin.name == 'trac':
+            self.ensureProjectPluginDirectoryExists(service)
             try:
                 self.register.create(service)
             except:
@@ -148,8 +149,12 @@ class Plugin(kforge.plugin.base.ServicePlugin):
         if trac_version < v0_9:
             modpythonHandler = 'trac.ModPythonHandler'
         urlBuilder = kforge.url.UrlScheme() 
-        logoutPath = urlBuilder.url_for_qualified('logout')
-        result = 'Redirect %(urlPath)s/logout ' + logoutPath
+        logoutPath = urlBuilder.url_for_qualified('logout') + '/'
+        result = """
+        Redirect %(urlPath)s/logout """ + logoutPath
+        loginPath = urlBuilder.url_for_qualified('login') + '/'
+        result += """
+        Redirect %(urlPath)s/login """ + loginPath
         result += """
         <Location %(urlPath)s>
           <IfModule mod_python.c>
