@@ -65,9 +65,11 @@ class UrlSchemeTest(TestCase):
         out = self.scheme.url_for('project')
         assert out == self._path('/project')
         out = self.scheme.url_for('project', action='search')
-        assert out == self._path('/project/search')
+        assert out == self._path('/project/search'), out
         out = self.scheme.url_for('project', action='read', id='annakarenina')
         assert out == self._path('/project/annakarenina')
+        out = self.scheme.url_for('project', action='delete', id='annakarenina')
+        assert out == self._path('/project/annakarenina/delete'), out
 
     def test_ProjectAdmin(self):
         out = self.scheme.url_for('project.admin', project='annakarenina',
@@ -122,10 +124,14 @@ class UrlSchemeTest(TestCase):
 
     def test_getServiceUrl(self):
         project_name = 'a_really_weird_name'
+        # Todo: Extract stub (from here and above).
         class ProjectStub:
             name = project_name
+        class PluginStub:
+            name = 'wiki'
         class ServiceStub:
             project = ProjectStub()
+            plugin = PluginStub()
             name = 'service_stub'
 
         out = self.scheme.getServiceUrl(ServiceStub())
